crabnet.data.materials\_data package
====================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   crabnet.data.materials_data.elasticity
   crabnet.data.materials_data.example_materials_property

Module contents
---------------

.. automodule:: crabnet.data.materials_data
   :members:
   :undoc-members:
   :show-inheritance:
